==> jc-1.4.0.tar.gz: gnu/xml/transform/URIResolverEntityResolver.h <==
// class gnu.xml.transform.URIResolverEntityResolver

// class file dependencies
// @dep_class f486a2d8ac6f25b4 gnu_xml_transform_URIResolverEntityResolver
// @dep_class 2a7152deee1944f1 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_gnu_xml_transform_URIResolverEntityResolver_H_
#define _JC_gnu_xml_transform_URIResolverEntityResolver_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_javax_xml_transform_URIResolver$object;
struct _jc_org_xml_sax_InputSource$object;

// Typedefs
typedef struct _jc_gnu_xml_transform_URIResolverEntityResolver$sub_refs	_jc_gnu_xml_transform_URIResolverEntityResolver$sub_refs;
typedef struct _jc_gnu_xml_transform_URIResolverEntityResolver$sub_nonrefs	_jc_gnu_xml_transform_URIResolverEntityResolver$sub_nonrefs;
typedef struct _jc_gnu_xml_transform_URIResolverEntityResolver$refs	_jc_gnu_xml_transform_URIResolverEntityResolver$refs;
typedef struct _jc_gnu_xml_transform_URIResolverEntityResolver$nonrefs	_jc_gnu_xml_transform_URIResolverEntityResolver$nonrefs;
typedef struct _jc_gnu_xml_transform_URIResolverEntityResolver$object	_jc_gnu_xml_transform_URIResolverEntityResolver$object;

typedef const struct _jc_gnu_xml_transform_URIResolverEntityResolver$vmethods	_jc_gnu_xml_transform_URIResolverEntityResolver$vmethods;
typedef const struct _jc_gnu_xml_transform_URIResolverEntityResolver$vtable	_jc_gnu_xml_transform_URIResolverEntityResolver$vtable;
typedef const struct _jc_gnu_xml_transform_URIResolverEntityResolver$vtype	_jc_gnu_xml_transform_URIResolverEntityResolver$vtype;

// Constructors
extern void _jc_gnu_xml_transform_URIResolverEntityResolver$method$_init$7794dce0119e7ab3(_jc_env *, struct _jc_gnu_xml_transform_URIResolverEntityResolver$object *, struct _jc_object *);

// Virtual methods
extern struct _jc_org_xml_sax_InputSource$object *_jc_gnu_xml_transform_URIResolverEntityResolver$method$resolveEntity$dc649396337500d5(_jc_env *, struct _jc_gnu_xml_transform_URIResolverEntityResolver$object *, struct _jc_java_lang_String$object *, struct _jc_java_lang_String$object *);

// Virtual method descriptors
extern _jc_method _jc_gnu_xml_transform_URIResolverEntityResolver$method_info$resolveEntity$dc649396337500d5;

// Virtual methods structure
struct _jc_gnu_xml_transform_URIResolverEntityResolver$vmethods {
	struct _jc_org_xml_sax_InputSource$object	*(*resolveEntity$dc649396337500d5)(_jc_env *, struct _jc_gnu_xml_transform_URIResolverEntityResolver$object *, struct _jc_java_lang_String$object *, struct _jc_java_lang_String$object *);
};

// Vtable
struct _jc_gnu_xml_transform_URIResolverEntityResolver$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_xml_transform_URIResolverEntityResolver$vmethods	gnu_xml_transform_URIResolverEntityResolver;
};

// Vtype
struct _jc_gnu_xml_transform_URIResolverEntityResolver$vtype {
	_jc_type			type;
	_jc_gnu_xml_transform_URIResolverEntityResolver$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_xml_transform_URIResolverEntityResolver$sub_refs {
	struct _jc_object	*resolver;
};

// Reference instance fields (object)
struct _jc_gnu_xml_transform_URIResolverEntityResolver$refs {
    _jc_gnu_xml_transform_URIResolverEntityResolver$sub_refs	gnu_xml_transform_URIResolverEntityResolver;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_xml_transform_URIResolverEntityResolver$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_xml_transform_URIResolverEntityResolver$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_xml_transform_URIResolverEntityResolver$sub_nonrefs	gnu_xml_transform_URIResolverEntityResolver;
};

// Object instance structure
struct _jc_gnu_xml_transform_URIResolverEntityResolver$object {
	_jc_gnu_xml_transform_URIResolverEntityResolver$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_xml_transform_URIResolverEntityResolver$vtype	*vtype;
	_jc_gnu_xml_transform_URIResolverEntityResolver$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_xml_transform_URIResolverEntityResolver$vtype _jc_gnu_xml_transform_URIResolverEntityResolver$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_xml_transform_URIResolverEntityResolver, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_xml_transform_URIResolverEntityResolver$class_object;

#endif	/* _JC_gnu_xml_transform_URIResolverEntityResolver_H_ */

==> jc-1.4.6.tar.gz: gnu/xml/transform/URIResolverEntityResolver.h <==
// class gnu.xml.transform.URIResolverEntityResolver

// class file dependencies
// @dep_class f486a2d8ac6f25b4 gnu_xml_transform_URIResolverEntityResolver
// @dep_class 1c4f1fc002fc96e5 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_gnu_xml_transform_URIResolverEntityResolver_H_
#define _JC_gnu_xml_transform_URIResolverEntityResolver_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_javax_xml_transform_URIResolver$object;
struct _jc_org_xml_sax_InputSource$object;

// Typedefs
typedef struct _jc_gnu_xml_transform_URIResolverEntityResolver$sub_refs	_jc_gnu_xml_transform_URIResolverEntityResolver$sub_refs;
typedef struct _jc_gnu_xml_transform_URIResolverEntityResolver$sub_nonrefs	_jc_gnu_xml_transform_URIResolverEntityResolver$sub_nonrefs;
typedef struct _jc_gnu_xml_transform_URIResolverEntityResolver$refs	_jc_gnu_xml_transform_URIResolverEntityResolver$refs;
typedef struct _jc_gnu_xml_transform_URIResolverEntityResolver$nonrefs	_jc_gnu_xml_transform_URIResolverEntityResolver$nonrefs;
typedef struct _jc_gnu_xml_transform_URIResolverEntityResolver$object	_jc_gnu_xml_transform_URIResolverEntityResolver$object;

typedef const struct _jc_gnu_xml_transform_URIResolverEntityResolver$vmethods	_jc_gnu_xml_transform_URIResolverEntityResolver$vmethods;
typedef const struct _jc_gnu_xml_transform_URIResolverEntityResolver$vtable	_jc_gnu_xml_transform_URIResolverEntityResolver$vtable;
typedef const struct _jc_gnu_xml_transform_URIResolverEntityResolver$vtype	_jc_gnu_xml_transform_URIResolverEntityResolver$vtype;

// Constructors
extern void _jc_gnu_xml_transform_URIResolverEntityResolver$method$_init$7794dce0119e7ab3(_jc_env *, struct _jc_gnu_xml_transform_URIResolverEntityResolver$object *, struct _jc_object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_org_xml_sax_InputSource$object *_jc_gnu_xml_transform_URIResolverEntityResolver$method$resolveEntity$dc649396337500d5(_jc_env *, struct _jc_gnu_xml_transform_URIResolverEntityResolver$object *, struct _jc_java_lang_String$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_gnu_xml_transform_URIResolverEntityResolver$method_info$resolveEntity$dc649396337500d5;

// Virtual methods structure
struct _jc_gnu_xml_transform_URIResolverEntityResolver$vmethods {
	struct _jc_org_xml_sax_InputSource$object	*(*resolveEntity$dc649396337500d5)(_jc_env *, struct _jc_gnu_xml_transform_URIResolverEntityResolver$object *, struct _jc_java_lang_String$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_gnu_xml_transform_URIResolverEntityResolver$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_xml_transform_URIResolverEntityResolver$vmethods	gnu_xml_transform_URIResolverEntityResolver;
};

// Vtype
struct _jc_gnu_xml_transform_URIResolverEntityResolver$vtype {
	_jc_type			type;
	_jc_gnu_xml_transform_URIResolverEntityResolver$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_xml_transform_URIResolverEntityResolver$sub_refs {
	struct _jc_object	*resolver;
};

// Reference instance fields (object)
struct _jc_gnu_xml_transform_URIResolverEntityResolver$refs {
    _jc_gnu_xml_transform_URIResolverEntityResolver$sub_refs	gnu_xml_transform_URIResolverEntityResolver;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_xml_transform_URIResolverEntityResolver$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_xml_transform_URIResolverEntityResolver$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_xml_transform_URIResolverEntityResolver$sub_nonrefs	gnu_xml_transform_URIResolverEntityResolver;
};

// Object instance structure
struct _jc_gnu_xml_transform_URIResolverEntityResolver$object {
	_jc_gnu_xml_transform_URIResolverEntityResolver$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_xml_transform_URIResolverEntityResolver$vtype	*vtype;
	_jc_gnu_xml_transform_URIResolverEntityResolver$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_xml_transform_URIResolverEntityResolver$vtype _jc_gnu_xml_transform_URIResolverEntityResolver$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_xml_transform_URIResolverEntityResolver, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_xml_transform_URIResolverEntityResolver$class_object;

#endif	/* _JC_gnu_xml_transform_URIResolverEntityResolver_H_ */
